[**Opções avançadas**](./introduction.md) > **Código do idioma** _(atual)_

---

#### Google

Fonte <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organizado por GPT-4o.

| Rótulo em Português | Rótulo | `Language Code` |
| --- | --- | --- |
| Amárico | Amharic | `am` |
| Árabe | Arabic | `ar` |
| Basco | Basque | `eu` |
| Bengali | Bengali | `bn` |
| Inglês (Reino Unido) | English (UK) | `en-GB` |
| Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| Búlgaro | Bulgarian | `bg` |
| Catalão | Catalan | `ca` |
| Cherokee | Cherokee | `chr` |
| Croata | Croatian | `hr` |
| Tcheco | Czech | `cs` |
| Dinamarquês | Danish | `da` |
| Holandês | Dutch | `nl` |
| Inglês (Estados Unidos) | English (US) | `en` |
| Estoniano | Estonian | `et` |
| Filipino | Filipino | `fil` |
| Finlandês | Finnish | `fi` |
| Francês | French | `fr` |
| Alemão | German | `de` |
| Grego | Greek | `el` |
| Gujarati | Gujarati | `gu` |
| Hebraico | Hebrew | `iw` |
| Hindi | Hindi | `hi` |
| Húngaro | Hungarian | `hu` |
| Islandês | Icelandic | `is` |
| Indonésio | Indonesian | `id` |
| Italiano | Italian | `it` |
| Japonês | Japanese | `ja` |
| 卡纳达语 | Kannada | `kn` |
| Coreano | Coreano | `ko` |
| Letão | Latvian | `lv` |
| Lituano | Lithuanian | `lt` |
| Malaio | Malay | `ms` |
| Malaiala | Malaiala | `ml` |
| Marathi | `mr` |
| Norueguês | Norwegian | `no` |
| Polonês | Polish | `pl` |
| Português (Portugal) | Português (Portugal) | `pt-PT` |
| Romeno | Romanian | `ro` |
| Russo | Russian | `ru` |
| Sérvio | Serbian | `sr` |
| Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| ------------ | ------------- | ------- | --- | ------------------- | ------------------- | ------- |
| 简体中文     | Chinese (Simplified) | `zh` | | Português           | Portuguese          | `pt`    |
| 繁體中文（台灣） | Chinese (Taiwan) | `zh-TW` | | Português (Portugal) | Portuguese (Portugal) | `pt-PT` |

---

### TRANSLATED TEXT

| Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| ------------------- | ------------------- | ------- |
| Português           | Portuguese          | `pt`    |
| Português (Portugal) | Portuguese (Portugal) | `pt-PT` |
| Eslovaco | Slovak | `sk` |
| Esloveno | Slovenian | `sl` |
| Espanhol | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| Sueco | Swedish | `sv` |
| Tâmil | Tamil | `ta` |
| Telugu | Telugu | `te` |
| Tailandês | Thai | `th` |
| Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| ------------ | ---------------- | ------- | --- | ------------------- | ------------------- | ------- |
| 中文（香港） | Chinese (Hong Kong) | `zh-HK` | | Português (Portugal) | Portuguese (Portugal) | `pt-PT` |

---

### TRANSLATED TEXT

| Chinês (Taiwan) | Chinese (Taiwan) | `zh-TW` | --- | Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| --------------- | ---------------- | ------- | --- | ------------------- | ------------------- | ------- |
| Chinês (Hong Kong) | Chinese (Hong Kong) | `zh-HK` | | Português (Portugal) | Portuguese (Portugal) | `pt-PT` |
| Turco | Turkish | `tr` |
| Urdu | Urdu | `ur` |
| Ucraniano | Ukrainian | `uk` |
| Vietnamita | Vietnamese | `vi` |
| Galês | Welsh | `cy` |


#### DeepL
Fonte <https://developers.deepl.com/docs/resources/supported-languages>, organizado por GPT-4o.

| Rótulo em chinês | Rótulo | `Language Code` | Suporta |
| --- | --- | --- | --- |
| Árabe | Arabic | `AR` | `source`, `target` |
| Búlgaro | Bulgarian | `BG` | `source`, `target` |
| Tcheco | Czech | `CS` | `source`, `target` |
| Dinamarquês | Danish | `DA` | `source`, `target` |
| Alemão | German | `DE` | `source`, `target` |
| Grego | `EL` | `source`, `target` |
| Português | Português | `PT` | `source`, `target` |
|
| Inglês (Americano) | English (American) | `EN-US` | `target` |
| Espanhol | Spanish | `ES` | `source`, `target` |
| Estoniano | Estonian | `ET` | `source`, `target` |
| Finlandês | Finnish | `FI` | `source`, `target` |
| Francês | French | `FR` | `source`, `target` |
| Húngaro | Hungarian | `HU` | `source`, `target` |
| Indonésio | Indonesian | `ID` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| Japonês | Japanese | `JA` | `source`, `target` |
| Coreano | `KO` | `source`, `target` |
| Lituano | Lithuanian | `LT` | `source`, `target` |
| Letão | Latvian | `LV` | `source`, `target` |
| Norueguês Bokmål | Norwegian Bokmål | `NB` | `source`, `target` |
| Holandês | Dutch | `NL` | `source`, `target` |
| Polonês | Polish | `PL` | `source`, `target` |
| Português | Portuguese | `PT` | `source`, `target` |
| Português (Brasil) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Português (Europeu) | Português (Europeu) | `PT-PT` | `target` |
| Romeno | Romanian | `RO` | `source`, `target` |
| Russo | Russian | `RU` | `source`, `target` |
| Eslovaco | Slovak | `SK` | `source`, `target` |
| Esloveno | Slovenian | `SL` | `source`, `target` |
| Sueco | Swedish | `SV` | `source`, `target` |
| Turco | Turkish | `TR` | `source`, `target` |
| Ucraniano | Ukrainian | `UK` | `source`, `target` |
| Português | Portuguese | `PT` | `source`, `target` |
|---|---|---|---|---|---|---|---|---|
| 中文 | Chinese | `ZH` | `source`, `target` | Português | Portuguese | `PT` | `source`, `target` |
| Português (Brasil) | Portuguese (Brazil) | `PT-BR` | `target` |
|--------------|----------------------|-----------|----------|--------|--------------------|----------------------|---------|----------|
| 主页         | Home                 | `ZH-HANS` | `source` |        | Início             | Home                 | `PT-BR` | `target` |
| 快速开始     | Getting Start        | `ZH-HANS` | `source` |        | Começar            | Getting Start        | `PT-BR` | `target` |
| 安装         | Installation         | `ZH-HANS` | `source` |        | Instalação          | Installation         | `PT-BR` | `target` |
| 命令行       | Command Line         | `ZH-HANS` | `source` |        | Linha de comando   | Command Line         | `PT-BR` | `target` |
| 使用         | Usage                | `ZH-HANS` | `source` |        | Uso                | Usage                | `PT-BR` | `target` |
| 语言代码     | Language Code        | `ZH-HANS` | `source` |        | Código do idioma   | Language Code        | `PT-BR` | `target` |
| 翻译服务文档 | Documentation of Translation Services | `ZH-HANS` | `source` |        | Documentação dos serviços de tradução | Documentation of Translation Services | `PT-BR` | `target` |
| 开始使用     | Getting Started      | `ZH-HANS` | `source` |        | Começar            | Getting Started      | `PT-BR` | `target` |
| 进阶选项     | Advanced             | `ZH-HANS` | `source` |        | Opções avançadas   | Advanced             | `PT-BR` | `target` |
| 支持的语言   | Supported Languages  | `ZH-HANS` | `source` |        | Idiomas suportados | Supported Languages  | `PT-BR` | `target` |
| 社区         | Community            | `ZH-HANS` | `source` |        | Comunidade         | Community            | `PT-BR` | `target` |
| 常见问题     | FAQ                  | `ZH-HANS` | `source` |        | Perguntas frequentes | FAQ                  | `PT-BR` | `target` |
| #### 谷歌     | #### Google          | `ZH-HANS` | `source` |        | #### Google        | #### Google          | `PT-BR` | `target` |
| #### 深度     | #### DeepL           | `ZH-HANS` | `source` |        | #### DeepL         | #### DeepL           | `PT-BR` | `target` |
| Português | Tradução
---|---|---|---
| 中文（繁体） | Chinês (Tradicional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Parte do conteúdo desta página foi traduzida pelo GPT e pode conter erros.</small></h6>